"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const unistore_1 = __importDefault(require("unistore"));
const signal_exit_1 = __importDefault(require("signal-exit"));
const clearConsole_1 = require("./clearConsole");
exports.store = unistore_1.default({ appUrl: null, bootstrap: true });
let registered = false;
exports.store.subscribe(state => {
    if (!registered) {
        registered = true;
        process.stderr.write('\u001B[?1049h');
        signal_exit_1.default(function () {
            process.stderr.write('\u001B[?1049l');
        });
    }
    clearConsole_1.clearConsole();
    if (state.bootstrap) {
        console.log(chalk_1.default.cyan('Starting the development server ...'));
        if (state.appUrl) {
            console.log();
            console.log(`  > Waiting on ${state.appUrl}`);
        }
        return;
    }
    if (state.loading) {
        console.log('Compiling ...');
        return;
    }
    if (state.errors) {
        console.log(chalk_1.default.red('Failed to compile.'));
        console.log();
        console.log(state.errors[0]);
        return;
    }
    if (state.warnings) {
        console.log(chalk_1.default.yellow('Compiled with warnings.'));
        console.log();
        console.log(state.warnings.join('\n\n'));
        return;
    }
    console.log(chalk_1.default.green('Compiled successfully!'));
    if (state.appUrl) {
        console.log();
        console.log(`  > Ready on ${state.appUrl}`);
    }
    console.log();
    console.log('Note that pages will be compiled when you first load them.');
});
